//*****************************************************************************
// Description     : Definition of command parameters for histogram measurement
// Target Device   : APV8508, APV8104
// Target Platform : Linux, C
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
#ifndef __CONFIGHIST_H__
#define __CONFIGHIST_H__

#include "device.h"
#include "local_define.h"


static DEVICE_CONFIG_LIST configHist[] = {
    { 0xB400002E, 0x0100 },     // ADC Read Size
    { 0xB4000030, 0x0001 },     // Trigger Select = CH1
    { 0xB4000032, 0x00FF },     // Edge Select
    { 0xB400008C, 0x000C },     // Wave Trigger Point
    { 0xB400011A, 0x0001 },     // Input Polarity(CH1) = Positive
    { 0xB400021A, 0x0001 },     //               (CH2)
    { 0xB400031A, 0x0001 },     //               (CH3)
    { 0xB400041A, 0x0001 },     //               (CH4)
    { 0xB400051A, 0x0001 },     //               (CH5)
    { 0xB400061A, 0x0001 },     //               (CH6)
    { 0xB400071A, 0x0001 },     //               (CH7)
    { 0xB400081A, 0x0001 },     //               (CH8)
    { 0xB4000036, 0x0000 },     // Free Run = OFF
    { 0xB400010C, 0x0001 },     // QDC Full Scale(CH1) = 1/2
    { 0xB400020C, 0x0001 },     //               (CH2)
    { 0xB400030C, 0x0001 },     //               (CH3)
    { 0xB400040C, 0x0001 },     //               (CH4)
    { 0xB400050C, 0x0001 },     //               (CH5)
    { 0xB400060C, 0x0001 },     //               (CH6)
    { 0xB400070C, 0x0001 },     //               (CH7)
    { 0xB400080C, 0x0001 },     //               (CH8)
    { 0xB4000160, 0x0007 },     // CFD Function(CH1)
    { 0xB4000260, 0x0007 },     //             (CH2)
    { 0xB4000360, 0x0007 },     //             (CH3)
    { 0xB4000460, 0x0007 },     //             (CH4)
    { 0xB4000560, 0x0007 },     //             (CH5)
    { 0xB4000660, 0x0007 },     //             (CH6)
    { 0xB4000760, 0x0007 },     //             (CH7)
    { 0xB4000860, 0x0007 },     //             (CH8)
    { 0xB4000162, 0x0004 },     // CFD Delay(CH1)
    { 0xB4000262, 0x0004 },     //          (CH2)
    { 0xB4000362, 0x0004 },     //          (CH3)
    { 0xB4000462, 0x0004 },     //          (CH4)
    { 0xB4000562, 0x0004 },     //          (CH5)
    { 0xB4000662, 0x0004 },     //          (CH6)
    { 0xB4000762, 0x0004 },     //          (CH7)
    { 0xB4000862, 0x0004 },     //          (CH8)
    { 0xB4000164, 0x0014 },     // CFD Walk(CH1)
    { 0xB4000264, 0x0010 },     //         (CH2)
    { 0xB4000364, 0x0010 },     //         (CH3)
    { 0xB4000464, 0x0010 },     //         (CH4)
    { 0xB4000564, 0x0010 },     //         (CH5)
    { 0xB4000664, 0x0010 },     //         (CH6)
    { 0xB4000764, 0x0010 },     //         (CH7)
    { 0xB4000864, 0x0010 },     //         (CH8)
    { 0xB4000166, 0x0032 },     // CFD Threshold(CH1)
    { 0xB4000266, 0x0020 },     //              (CH2)
    { 0xB4000366, 0x0020 },     //              (CH3)
    { 0xB4000466, 0x0020 },     //              (CH4)
    { 0xB4000566, 0x0020 },     //              (CH5)
    { 0xB4000666, 0x0020 },     //              (CH6)
    { 0xB4000766, 0x0020 },     //              (CH7)
    { 0xB4000866, 0x0020 },     //              (CH8)
    { 0xB4000168, 0x0014 },     // QDC LLD(CH1)
    { 0xB4000268, 0x0014 },     //        (CH2)
    { 0xB4000368, 0x0014 },     //        (CH3)
    { 0xB4000468, 0x0014 },     //        (CH4)
    { 0xB4000568, 0x0014 },     //        (CH5)
    { 0xB4000668, 0x0014 },     //        (CH6)
    { 0xB4000768, 0x0014 },     //        (CH7)
    { 0xB4000868, 0x0014 },     //        (CH8)
    { 0xB400016A, 0x1FFF },     // QDC ULD(CH1)
    { 0xB400026A, 0x1FFF },     //        (CH2)
    { 0xB400036A, 0x1FFF },     //        (CH3)
    { 0xB400046A, 0x1FFF },     //        (CH4)
    { 0xB400056A, 0x1FFF },     //        (CH5)
    { 0xB400066A, 0x1FFF },     //        (CH6)
    { 0xB400076A, 0x1FFF },     //        (CH7)
    { 0xB400086A, 0x1FFF },     //        (CH8)
    { 0xB400016E, 0x00FC },     // Baseline Restore Filter(CH1)
    { 0xB400026E, 0x00FC },     //                        (CH2)
    { 0xB400036E, 0x00FC },     //                        (CH3)
    { 0xB400046E, 0x00FC },     //                        (CH4)
    { 0xB400056E, 0x00FC },     //                        (CH5)
    { 0xB400066E, 0x00FC },     //                        (CH6)
    { 0xB400076E, 0x00FC },     //                        (CH7)
    { 0xB400086E, 0x00FC },     //                        (CH8)
    { 0xB4000060, 0x0000 },     // Calc FIFO IRQ Trigger
    { 0xB4000068, 0x0000 },     // Calc Disc Mode = CFD
    { 0xB400006E, 0x0000 },     // TAC Integral Range
    { 0xB40001C0, 0x0002 },     // QDC Pretrigger(CH1) = -16ns
    { 0xB40002C0, 0x0002 },     //               (CH2)
    { 0xB40003C0, 0x0002 },     //               (CH3)
    { 0xB40004C0, 0x0002 },     //               (CH4)
    { 0xB40005C0, 0x0002 },     //               (CH5)
    { 0xB40006C0, 0x0002 },     //               (CH6)
    { 0xB40007C0, 0x0002 },     //               (CH7)
    { 0xB40008C0, 0x0002 },     //               (CH8)
    { 0xB40001C2, 0x0000 },     // Wave Select(CH1)
    { 0xB40002C2, 0x0001 },     //            (CH2)
    { 0xB40003C2, 0x0002 },     //            (CH3)
    { 0xB40004C2, 0x0300 },     //            (CH4)
    { 0xB40005C2, 0x0400 },     //            (CH5)
    { 0xB40006C2, 0x0500 },     //            (CH6)
    { 0xB40007C2, 0x0600 },     //            (CH7)
    { 0xB40008C2, 0x0700 },     //            (CH8)
    { 0xB40001C6, 0x0001 },     // QDC Filter(CH1)
    { 0xB40002C6, 0x0001 },     //           (CH2)
    { 0xB40003C6, 0x0001 },     //           (CH3)
    { 0xB40004C6, 0x0001 },     //           (CH4)
    { 0xB40005C6, 0x0001 },     //           (CH5)
    { 0xB40006C6, 0x0001 },     //           (CH6)
    { 0xB40007C6, 0x0001 },     //           (CH7)
    { 0xB40008C6, 0x0001 },     //           (CH8)
    { 0xB40001C8, 0x0001 },     // QDC Select(CH1) = Sum
    { 0xB40002C8, 0x0001 },     //           (CH2)
    { 0xB40003C8, 0x0001 },     //           (CH3)
    { 0xB40004C8, 0x0001 },     //           (CH4)
    { 0xB40005C8, 0x0001 },     //           (CH5)
    { 0xB40006C8, 0x0001 },     //           (CH6)
    { 0xB40007C8, 0x0001 },     //           (CH7)
    { 0xB40008C8, 0x0001 },     //           (CH8)
    { 0xB400010E, 0x0001 },     // Analog Gain(CH1)
    { 0xB400020E, 0x0001 },     //            (CH2)
    { 0xB400030E, 0x0001 },     //            (CH3)
    { 0xB400040E, 0x0001 },     //            (CH4)
    { 0xB400050E, 0x0001 },     //            (CH5)
    { 0xB400060E, 0x0001 },     //            (CH6)
    { 0xB400070E, 0x0001 },     //            (CH7)
    { 0xB400080E, 0x0001 },     //            (CH8)
    { 0xB4000170, 0x0800 },     // Analog Offset(CH1)
    { 0xB4000270, 0x0800 },     //              (CH2)
    { 0xB4000370, 0x0800 },     //              (CH3)
    { 0xB4000470, 0x0800 },     //              (CH4)
    { 0xB4000570, 0x0800 },     //              (CH5)
    { 0xB4000670, 0x0800 },     //              (CH6)
    { 0xB4000770, 0x0800 },     //              (CH7)
    { 0xB4000870, 0x0800 },     //              (CH8)
    { 0xB40001B0, 0x0001 },     // ADC Parameter Write Enable(CH1) = Enable
    { 0xB40002B0, 0x0001 },     //                           (CH2)
    { 0xB40003B0, 0x0001 },     //                           (CH3)
    { 0xB40004B0, 0x0001 },     //                           (CH4)
    { 0xB40005B0, 0x0001 },     //                           (CH5)
    { 0xB40006B0, 0x0001 },     //                           (CH6)
    { 0xB40007B0, 0x0001 },     //                           (CH7)
    { 0xB40008B0, 0x0001 },     //                           (CH8)
    { 0xB40001B4, 0x0078 },     // ADC Coarse Offset 0(CH1)
    { 0xB40002B4, 0x0074 },     //                    (CH2)
    { 0xB40003B4, 0x007E },     //                    (CH3)
    { 0xB40004B4, 0x0076 },     //                    (CH4)
    { 0xB40005B4, 0x0072 },     //                    (CH5)
    { 0xB40006B4, 0x0070 },     //                    (CH6)
    { 0xB40007B4, 0x0070 },     //                    (CH7)
    { 0xB40008B4, 0x0070 },     //                    (CH8)
    { 0xB40001B6, 0x0069 },     // ADC Coarse Offset 1(CH1)
    { 0xB40002B6, 0x0070 },     //                    (CH2)
    { 0xB40003B6, 0x0074 },     //                    (CH3)
    { 0xB40004B6, 0x0076 },     //                    (CH4)
    { 0xB40005B6, 0x0070 },     //                    (CH5)
    { 0xB40006B6, 0x0076 },     //                    (CH6)
    { 0xB40007B6, 0x0072 },     //                    (CH7)
    { 0xB40008B6, 0x006F },     //                    (CH8)
    { 0xB40001CC, 0x006C },     // ADC Fine Offset 0(CH1)
    { 0xB40002CC, 0x0066 },     //                  (CH2)
    { 0xB40003CC, 0x0066 },     //                  (CH3)
    { 0xB40004CC, 0x0062 },     //                  (CH4)
    { 0xB40005CC, 0x0076 },     //                  (CH5)
    { 0xB40006CC, 0x0082 },     //                  (CH6)
    { 0xB40007CC, 0x001E },     //                  (CH7)
    { 0xB40008CC, 0x006A },     //                  (CH8)
    { 0xB40001CE, 0x005A },     // ADC Fine Offset 1(CH1)
    { 0xB40002CE, 0x0080 },     //                  (CH2)
    { 0xB40003CE, 0x004C },     //                  (CH3)
    { 0xB40004CE, 0x006A },     //                  (CH4)
    { 0xB40005CE, 0x00BA },     //                  (CH5)
    { 0xB40006CE, 0x0074 },     //                  (CH6)
    { 0xB40007CE, 0x0064 },     //                  (CH7)
    { 0xB40008CE, 0x0028 },     //                  (CH8)
    { 0xB40001B8, 0x000E },     // ADC Coarse Gain 0(CH1)
    { 0xB40002B8, 0x000E },     //                  (CH2)
    { 0xB40003B8, 0x000E },     //                  (CH3)
    { 0xB40004B8, 0x000E },     //                  (CH4)
    { 0xB40005B8, 0x000E },     //                  (CH5)
    { 0xB40006B8, 0x000E },     //                  (CH6)
    { 0xB40007B8, 0x000E },     //                  (CH7)
    { 0xB40008B8, 0x000E },     //                  (CH8)
    { 0xB40001BA, 0x000E },     // ADC Coarse Gain 1(CH1)
    { 0xB40002BA, 0x000E },     //                  (CH2)
    { 0xB40003BA, 0x000E },     //                  (CH3)
    { 0xB40004BA, 0x000E },     //                  (CH4)
    { 0xB40005BA, 0x000E },     //                  (CH5)
    { 0xB40006BA, 0x000E },     //                  (CH6)
    { 0xB40007BA, 0x000E },     //                  (CH7)
    { 0xB40008BA, 0x000E },     //                  (CH8)
    { 0xB40001BC, 0x008B },     // ADC Middle Gain 0(CH1)
    { 0xB40002BC, 0x0088 },     //                  (CH2)
    { 0xB40003BC, 0x0083 },     //                  (CH3)
    { 0xB40004BC, 0x0091 },     //                  (CH4)
    { 0xB40005BC, 0x0086 },     //                  (CH5)
    { 0xB40006BC, 0x008B },     //                  (CH6)
    { 0xB40007BC, 0x0088 },     //                  (CH7)
    { 0xB40008BC, 0x0072 },     //                  (CH8)
    { 0xB40001BE, 0x007F },     // ADC Middle Gain 1(CH1)
    { 0xB40002BE, 0x008C },     //                  (CH2)
    { 0xB40003BE, 0x007D },     //                  (CH3)
    { 0xB40004BE, 0x0079 },     //                  (CH4)
    { 0xB40005BE, 0x007A },     //                  (CH5)
    { 0xB40006BE, 0x0075 },     //                  (CH6)
    { 0xB40007BE, 0x0082 },     //                  (CH7)
    { 0xB40008BE, 0x008E },     //                  (CH8)
    { 0xB40001D8, 0x0001 },     // FRC Start Count(CH1)
    { 0xB40002D8, 0x0001 },     //                (CH2)
    { 0xB40003D8, 0x0001 },     //                (CH3)
    { 0xB40004D8, 0x0001 },     //                (CH4)
    { 0xB40005D8, 0x0001 },     //                (CH5)
    { 0xB40006D8, 0x0001 },     //                (CH6)
    { 0xB40007D8, 0x0001 },     //                (CH7)
    { 0xB40008D8, 0x0001 },     //                (CH8)
    { 0xB40001DA, 0x000A },     // FRC Stop Count(CH1)
    { 0xB40002DA, 0x000A },     //               (CH2)
    { 0xB40003DA, 0x000A },     //               (CH3)
    { 0xB40004DA, 0x000A },     //               (CH4)
    { 0xB40005DA, 0x000A },     //               (CH5)
    { 0xB40006DA, 0x000A },     //               (CH6)
    { 0xB40007DA, 0x000A },     //               (CH7)
    { 0xB40008DA, 0x000A },     //               (CH8)
    { 0xB40001DC, 0x0013 },     // QDC Integral Range(CH1)
    { 0xB40002DC, 0x0013 },     //                   (CH2)
    { 0xB40003DC, 0x0013 },     //                   (CH3)
    { 0xB40004DC, 0x0013 },     //                   (CH4)
    { 0xB40005DC, 0x0013 },     //                   (CH5)
    { 0xB40006DC, 0x0013 },     //                   (CH6)
    { 0xB40007DC, 0x0013 },     //                   (CH7)
    { 0xB40008DC, 0x0013 },     //                   (CH8)
    { 0xB40001DE, 0x0000 },     // Input Signal Type(CH1)
    { 0xB40002DE, 0x0000 },     //                  (CH2)
    { 0xB40003DE, 0x0000 },     //                  (CH3)
    { 0xB40004DE, 0x0000 },     //                  (CH4)
    { 0xB40005DE, 0x0000 },     //                  (CH5)
    { 0xB40006DE, 0x0000 },     //                  (CH6)
    { 0xB40007DE, 0x0000 },     //                  (CH7)
    { 0xB40008DE, 0x0000 },     //                  (CH8)
    { 0xB4000110, 0x0058 },     // Rise Judge Threshold(CH1)
    { 0xB4000210, 0x0058 },     //                     (CH2)
    { 0xB4000310, 0x0058 },     //                     (CH3)
    { 0xB4000410, 0x0058 },     //                     (CH4)
    { 0xB4000510, 0x0058 },     //                     (CH5)
    { 0xB4000610, 0x0058 },     //                     (CH6)
    { 0xB4000710, 0x0058 },     //                     (CH7)
    { 0xB4000810, 0x0058 },     //                     (CH8)
    { 0xB40001D0, 0x0000 },     // Time Stamp Timing(CH1) = CFD
    { 0xB40002D0, 0x0000 },     //                  (CH2)
    { 0xB40003D0, 0x0000 },     //                  (CH3)
    { 0xB40004D0, 0x0000 },     //                  (CH4)
    { 0xB40005D0, 0x0000 },     //                  (CH5)
    { 0xB40006D0, 0x0000 },     //                  (CH6)
    { 0xB40007D0, 0x0000 },     //                  (CH7)
    { 0xB40008D0, 0x0000 },     //                  (CH8)
    { 0xB4000090, 0x0000 },     // Data Clear = Clear
    { 0xB4000090, 0x0001 },     // Data Clear = None
    { 0xB4000090, 0x0000 },     // Data Clear = Clear
    { 0xB4000026, DEVICE_SAMPLING },  // ADC Sampling Bit
    { 0x00000000, 0x0000 }  // end mark
};


#endif // __CONFIGHIST_H__
