//*****************************************************************************
// Description     : Declaration and macro definition for SiTCP communication
// Target Device   : APV8508, APV8104
// Target Platform : Linux, C
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
#ifndef __SITCP_H__
#define __SITCP_H__

#include "sys_compatible.h"


//******************** macro definition ********************
// command communication: header common part
#define SITCP_VER_TYPE              ((unsigned char)(0xff))  // version, type

// command communication: read command flag
#define SITCP_READ_REQ_CMDFLAG      ((unsigned char)(0xc0))  // request
#define SITCP_READ_ACK_CMDFLAG      ((unsigned char)(0xc8))  // acknowledge

// command communication: write command flag
#define SITCP_WRITE_REQ_CMDFLAG     ((unsigned char)(0x80))  // request
#define SITCP_WRITE_ACK_CMDFLAG     ((unsigned char)(0x88))  // acknowledge

#define SITCP_MAX_CMD_DATABYTE      (256)    // maximum size of data

// Size of the buffer of socket
#define SITCP_SOCKBUF_CMD     (16 * 1024)    // for command communication(16kB)
#define SITCP_SOCKBUF_DATA  (1024 * 1024)    // for receiving data(1MB)


//******************** structure type definition ********************
// header for command communication
typedef struct sitcp_header {
    unsigned char ver_type;      // version(4bit), type(4bit)
    unsigned char cmd_flag;      // command(4bit), flag(4bit)
    unsigned char id;            // identifier(0-255)
    unsigned char length;        // data length(byte)
    unsigned int  address;       // command address(32bit)
} SITCP_HEADER;

// data format for command communication
typedef struct sitcp_format {
    SITCP_HEADER        header;
    union {
        unsigned char   u08[SITCP_MAX_CMD_DATABYTE/1];    // unit of 8bit
        unsigned short  u16[SITCP_MAX_CMD_DATABYTE/2];    // unit of 16bit
        unsigned int    u32[SITCP_MAX_CMD_DATABYTE/4];    // unit of 32bit
        unsigned qword  u64[SITCP_MAX_CMD_DATABYTE/8];    // unit of 64bit
    } data;
} SITCP_FORMAT;

// encapsulate structure for reference all sockets for communication
typedef struct sitcp_com {
    int   cmd_socket;    // UDP socket for command communication
    int   data_socket;   // TCP socket for fast data transfer
} SITCP_COM;


//******************** prototype declaration ********************
extern int sitcp_connect(SITCP_COM*);
extern void sitcp_disconnect(SITCP_COM*);

extern unsigned short sitcp_read_16bit(SITCP_COM*, unsigned int, int*);
extern unsigned int   sitcp_read_32bit(SITCP_COM*, unsigned int, int*);
extern unsigned qword sitcp_read_48bit(SITCP_COM*, unsigned int, int*);
extern unsigned qword sitcp_read_64bit(SITCP_COM*, unsigned int, int*);

extern int sitcp_write_16bit(SITCP_COM*, unsigned int, unsigned short);
extern int sitcp_write_32bit(SITCP_COM*, unsigned int, unsigned int);
extern int sitcp_write_48bit(SITCP_COM*, unsigned int, unsigned qword);
extern int sitcp_write_64bit(SITCP_COM*, unsigned int, unsigned qword);

extern int sitcp_recv_data(SITCP_COM*, char*, int, int);

extern unsigned qword sitcp_hton64(unsigned qword);
extern unsigned qword sitcp_ntoh64(unsigned qword);


#endif // __SITCP_H__

