//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APV8508, APV8104
// Target Platform : Linux, C
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "file.h"
#include "local_define.h"


//#########################################################################
//  Name      : file_write_header
//  Function  : write header to the text file
//  Arguments :
//      in pName    : file name
//      in now_time : actual measurement time(msec)
//      in out_cnt  : pointer to the array of output count total
//      in out_cps  : pointer to the array of output count rate(cps)
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_header(char *pName, unsigned int now_time,
                      unsigned int *out_cnt, unsigned int *out_cps)
{
    FILE *fp;
	int i;

    // open file(create)
    fp = fopen(pName, "wt");
    if (fp == NULL) {
        return(-1);
    }

    // write header information
    fprintf(fp, "[header]\n");
    fprintf(fp, "Real time(s), %d\n", now_time/1000);

    fprintf(fp, "Output count");
	for (i = 0; i < DEVICE_MAX_CHNUM; i++) {
		fprintf(fp, ", %d", *(out_cnt + i) );
	}
	fprintf(fp, "\n");

    fprintf(fp, "Output rate(cps)");
	for (i = 0; i < DEVICE_MAX_CHNUM; i++) {
		fprintf(fp, ", %d", *(out_cps + i) );
	}
	fprintf(fp, "\n");

    // close file
    fclose(fp);

    return(0);
}


//#########################################################################
//  Name      : file_write_data
//  Function  : write data to the text file
//  Arguments :
//      in pName : file name
//      in pBuff : array of data
//  Return :
//       0 : success
//      -1 : failed to open file
//      -2 : failed to seek
//#########################################################################
int file_write_data(char *pName, unsigned int pBuff[][NUM_DATA])
{
    FILE *fp;
    int  ret;
    int  i, j;
    unsigned int *p;

    // open file(append)
    fp = fopen(pName, "rt+");
    if (fp == NULL) {
        return(-1);
    }

    // move to end of the file
    ret = fseek(fp, (int)0, SEEK_END);
    if (ret != 0) {
        fclose(fp);
        return(-2);
    }

    // write data
    fprintf(fp, "[data]\n");
    for (i = 0; i < NUM_DATA; i++) {
        fprintf(fp, "%d", pBuff[0][i]);         // CH1
        for (j = 1; j < DEVICE_MAX_CHNUM; j++) {
            fprintf(fp, ",%d", pBuff[j][i]);    // CH2-
        }
        fprintf(fp, "\n");
    }

    // close file
    fclose(fp);

    return(i);
}
